@@ -1,7 +1,11 @@
+import logging
+
 from smalld import SmallD
 
 smalld = SmallD.v8()
 
+logging.basicConfig(level=logging.DEBUG)
+
 
 @smalld.on_message_create
 def on_message(msg):
