@@ -1,18 +1,18 @@
-class SmallDException(Exception):
+class SmallDError(Exception):
     pass
 
 
-class HttpError(SmallDException):
+class HttpError(SmallDError):
     def __init__(self, *args, response=None, **kwargs):
         self.response = response
         super().__init__(*args, **kwargs)
 
 
-class NetworkError(SmallDException):
+class NetworkError(SmallDError):
     pass
 
 
-class RateLimitError(SmallDException):
+class RateLimitError(SmallDError):
     def __init__(self, reset, *, is_global=False):
         super().__init__(f"rate limited until {reset}")
         self.reset = reset
